@@ -7,7 +7,8 @@ class JijGPUSASampler(JijCloudSampler):
 
     def sample(self, bqm,
                beta_min=None, beta_max=None,
-               num_reads=1, mc_steps=100):
+               num_reads=1, mc_steps=100,
+               timeout=None):
         """sample ising
         Args:
             bqm (:obj:`dimod.BinaryQuadraticModel`): Binary quadratic model.
@@ -15,7 +16,7 @@ class JijGPUSASampler(JijCloudSampler):
             beta_max (float, optional): maximum beta (final beta in SA).
             num_reads (int, optional): number of samples. Defaults to 1.
             mc_steps (int, optional): number of MonteCarlo steps.
-
+            timeout (float optional): number of timeout for post request. Defaults to None. 
         Returns:
             dimod.SampleSet: store minimum energy samples
                              .info['energy'] store all sample energies
@@ -28,4 +29,5 @@ class JijGPUSASampler(JijCloudSampler):
         return super().sample(
             bqm, num_reads, mc_steps,
             beta_min=beta_min, beta_max=beta_max,
+            timeout=timeout
         )
